@@ -92,8 +92,8 @@ private:
   DIFile *getFile(const SPIRVId SourceId);
 
   DIFile *getDIFile(const std::string &FileName,
-                    Optional<DIFile::ChecksumInfo<StringRef>> CS = None,
-                    Optional<std::string> Source = None);
+                    std::optional<DIFile::ChecksumInfo<StringRef>> CS = std::nullopt,
+                    std::optional<std::string> Source = std::nullopt);
   DIFile *getDIFile(const SPIRVEntry *E);
   unsigned getLineNo(const SPIRVEntry *E);
 
@@ -185,7 +185,6 @@ private:
   Module *M;
   std::unordered_map<SPIRVId, std::unique_ptr<DIBuilder>> BuilderMap;
   SPIRVToLLVM *SPIRVReader;
-  DICompileUnit *CU;
   bool Enable;
   std::unordered_map<std::string, DIFile *> FileMap;
   std::unordered_map<SPIRVId, DISubprogram *> FuncMap;
@@ -211,13 +210,13 @@ private:
     return nullptr;
   }
   const std::string &getString(const SPIRVId Id);
-  Optional<std::string> getStringSourceContinued(const SPIRVId Id,
-                                                 SPIRVExtInst *DebugInst);
+  std::optional<std::string> getStringSourceContinued(const SPIRVId Id,
+                                                      SPIRVExtInst *DebugInst);
   SPIRVWord getConstantValueOrLiteral(const std::vector<SPIRVWord> &,
                                       const SPIRVWord,
                                       const SPIRVExtInstSetKind);
   std::string findModuleProducer();
-  Optional<DIFile::ChecksumInfo<StringRef>> ParseChecksum(StringRef Text);
+  std::optional<DIFile::ChecksumInfo<StringRef>> ParseChecksum(StringRef Text);
 
   // BuildIdentifier and StoragePath must both be set or both unset.
   // If StoragePath is empty both variables are unset and not valid.
